<?php
class UsuariosController {
  static public function ctrLOVUsuarios() {
    $respuesta = UsuariosModel::mdlLOVUsuarios();
    return $respuesta;
  }
  static public function ctrListarUsuarios() {
    $respuesta = UsuariosModel::mdlListarUsuarios();
    return $respuesta;
  }
  static public function ctrDatosUsuario($id) {
    $respuesta = UsuariosModel::mdlDatosUsuario($id);
    return $respuesta;
  }



  static public function ctrDatosCurso($id) {
    $respuesta = UsuariosModel::mdlDatosCurso($id);
    return $respuesta;
  }
  static public function ctrGuardarCurso($todos_los_campos) {
    $respuesta = UsuariosModel::mdlGuardarCurso($todos_los_campos);
    return $respuesta;
  }
  static public function ctrListarDatosCurso() {
    $respuesta = UsuariosModel::mdlListarDatosCurso();
    return $respuesta;
  }
  static public function ctrNuevoUsuario($todos_los_campos) {
    $respuesta = UsuariosModel::mdlNuevoUsuario($todos_los_campos);
    return $respuesta;
  }
  static public function ctrBorrarUsuario($id) {
    $respuesta = UsuariosModel::mdlBorrarUsuario($id);
    return $respuesta;
  }
  static public function ctrEditarUsuario($todos_los_campos) {
    $respuesta = UsuariosModel::mdlEditarUsuario($todos_los_campos);
    return $respuesta;
  }
}
